@@ -93,7 +93,28 @@ func IsMachoOrImg4(filePath string) (bool, error) {
 
 type Asn1Header struct {
 	Raw  asn1.RawContent
-	Name string
+	Name string `asn1:"ia5"` // IM4P
+}
+
+func IsImg4(filePath string) (bool, error) {
+	if filepath.Ext(filePath) == ".img4" {
+		return true, nil
+	}
+
+	data, err := os.ReadFile(filePath)
+	if err != nil {
+		return false, fmt.Errorf("failed to read file %s: %w", filePath, err)
+	}
+
+	var hdr Asn1Header
+	if _, err := asn1.Unmarshal(data, &hdr); err != nil {
+		return false, fmt.Errorf("failed to ASN.1 parse header: %v", err)
+	}
+
+	if hdr.Name == "IMG4" {
+		return true, nil
+	}
+	return false, nil
 }
 
 func IsIm4p(filePath string) (bool, error) {
@@ -101,13 +122,10 @@ func IsIm4p(filePath string) (bool, error) {
 		return true, nil
 	}
 
-	f, err := os.Open(filePath)
+	data, err := os.ReadFile(filePath)
 	if err != nil {
-		return false, fmt.Errorf("failed to open file %s: %w", filePath, err)
+		return false, fmt.Errorf("failed to read file %s: %w", filePath, err)
 	}
-	defer f.Close()
-
-	data := make([]byte, 10)
 
 	var hdr Asn1Header
 	if _, err := asn1.Unmarshal(data, &hdr); err != nil {
